// WebPageDownloader.java
//
// Informatics 45 Spring 2010
// Code Example: Downloading a Web Page from a Java Program
//
// This program asks the user to specify a URL (like the addresses you might
// type into a web browser), then downloads the corresponding page and prints
// it to the console.  For example, if you enter this URL:
//
//     http://www.ics.uci.edu/~thornton/inf45/
//
// then you'll see the front page of the Informatics 45 web site.  You won't
// see it the way your browser shows it to you; you'll only see its HTML
// source code.  But it's an exciting start!
//
// Note, too, that this program makes no attempt to handle exceptions and is
// not organized at all -- it just does everything in a main() method.  You
// might well want to use some of this code in your own project, though, of
// course, you'd want to organize it better and handle exceptions in a
// reasonable manner.

package inf45.spring2010.examples.web1;

import java.net.URL;
import java.net.URLConnection;
import java.util.Scanner;


public class WebPageDownloader
{
	public static void main(String[] args)
	throws Exception
	{
		// We'll begin by asking the user the URL of the page they'd like to
		// download.
		Scanner consoleIn = new Scanner(System.in);
		
		System.out.print("URL: ");
		String url = consoleIn.nextLine();
		
		// Connecting to a URL via HTTP is as simple as doing these two things:
		// create a URL object that represents the URL, then open a connection
		// to it, which gives you back a URLConnection.  A URLConnection is
		// actually a wrapper around a socket connection, handling the details
		// of HTTP for us.  Not surprisingly, then, URLConnections have input
		// and output streams, just as sockets do.  When we want to read what
		// the server sends us, we read from the input stream; when we want to
		// write additional information (i.e., a POST), we write to the output
		// stream.  In this case, we're using GET, so we don't need to write
		// additional data; we can safely ignore the output stream.
		URL chosenURL = new URL(url);
		URLConnection connection = chosenURL.openConnection();

		// Here, we'll just read the entire contents of the URLConnection's
		// input stream and print it to the console.  Notice that, since web
		// pages are text (or, at least, the HTML source code is text), we
		// can use a Scanner, just like when we read from a file or a socket's
		// input stream.
		Scanner connectionIn = new Scanner(connection.getInputStream());
		
		while (connectionIn.hasNextLine())
		{
			System.out.println(connectionIn.nextLine());
		}
		
		// We're done with the input stream, so we'll close the Scanner, which
		// will in turn close the input stream.
		connectionIn.close();
	}
}
